@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Changes;
 
-use 5.010;
+use 5.010001;
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
@@ -12,7 +12,7 @@ use Moose::Autobox;
 use Pod::Elemental;
 use Pod::Elemental::Element::Nested;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # regex
 has exclude_modules => (
@@ -134,17 +134,19 @@ sub weave_section {
 1;
 # ABSTRACT: Add a CHANGES POD section
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pod::Weaver::Section::Changes - Add a CHANGES POD section
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Pod::Weaver::Section::Changes (from Perl distribution Pod-Weaver-Section-Changes), released on 2015-04-01.
 
 =head1 SYNOPSIS
 
@@ -154,8 +156,9 @@ In your C<weaver.ini>:
 
 =head1 DESCRIPTION
 
-Inserting information in distribution's C<Changes> to main module's POD can be a
-convenience for your module users.
+This plugin inserts C<Changes> entries to POD section CHANGES. I used to think
+this is a good idea because I can look at the module's Changes history right
+from the POD. I've since repented :-)
 
 Changes is parsed using L<CPAN::Changes> and markup in text entries are
 currently assumed to be POD too.
@@ -168,16 +171,31 @@ L<Pod::Weaver>
 
 L<CPAN::Changes>
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Section-Changes>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com///github.com/perlancar/perl-Pod-Weaver-Section-Changes>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Changes>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
